---
title: <span class="badge object-type-scalar"></span> RowsPerSecond
---
# <span class="badge object-type-scalar"></span> RowsPerSecond

Throughput: rows/sec (rps)

## Definition

```python
# Throughput: rows/sec (rps)
RowsPerSecond: typing.Literal["rowsps"] = "rowsps"
```
